@@ -19,17 +19,21 @@ using System;
 using System.Collections.Generic;
 
 using LongoMatch.Interfaces;
+using LongoMatch.Store;
+using LongoMatch.Common;
 
 namespace LongoMatch.Stats
 {
 	public class CategoryStats: Stat
 	{
 		List <SubCategoryStat> subcatStats;
+		Category cat;
 		
-		public CategoryStats (string name, int totalCount, int localTeamCount, int visitorTeamCount):
-			base (name, totalCount, localTeamCount, visitorTeamCount)
+		public CategoryStats (Category cat, int totalCount, int localTeamCount, int visitorTeamCount):
+			base (cat.Name, totalCount, localTeamCount, visitorTeamCount)
 		{
 			subcatStats = new List<SubCategoryStat>();
+			this.cat = cat;
 		}
 		
 		public List<SubCategoryStat> SubcategoriesStats {
@@ -38,6 +42,48 @@ namespace LongoMatch.Stats
 			}
 		}
 		
+		public Category Category {
+			get {
+				return cat;
+			}
+		}
+		
+		public List<Coordinates> FieldCoordinates {
+			get; set;
+		}
+		
+		public List<Coordinates> HalfFieldCoordinates {
+			get; set;
+		}
+		
+		public List<Coordinates> GoalCoordinates {
+			get; set;
+		}
+		
+		public List<Coordinates> HomeFieldCoordinates {
+			get; set;
+		}
+		
+		public List<Coordinates> HomeHalfFieldCoordinates {
+			get; set;
+		}
+		
+		public List<Coordinates> HomeGoalCoordinates {
+			get; set;
+		}
+		
+		public List<Coordinates> AwayFieldCoordinates {
+			get; set;
+		}
+		
+		public List<Coordinates> AwayHalfFieldCoordinates {
+			get; set;
+		}
+		
+		public List<Coordinates> AwayGoalCoordinates {
+			get; set;
+		}
+		
 		public void AddSubcatStat (SubCategoryStat subcatStat) {
 			subcatStats.Add(subcatStat);
 		}
