@@ -118,5 +118,11 @@ namespace LongoMatch.Video.Common
 		Par,
 	}
 
-	
+	public enum SeekType {
+		Keyframe,
+		Accurate,
+		StepUp,
+		StepDown,
+		None
+	}
 }
