@@ -117,6 +117,11 @@ gst_video_encoder_finalize (GObject * object)
 {
   GstVideoEncoder *gve = (GstVideoEncoder *) object;
 
+  if (gve->priv->update_id != 0) {
+    g_source_remove (gve->priv->update_id);
+    gve->priv->update_id = 0;
+  }
+
   GST_DEBUG_OBJECT (gve, "Finalizing.");
   if (gve->priv->bus) {
     /* make bus drop all messages to make sure none of our callbacks is ever
@@ -137,7 +142,7 @@ gst_video_encoder_finalize (GObject * object)
 
   if (gve->priv->input_files) {
     g_list_foreach (gve->priv->input_files, (GFunc) g_free, NULL);
-    g_free (gve->priv->input_files);
+    g_list_free (gve->priv->input_files);
     gve->priv->input_files = NULL;
   }
 
@@ -148,11 +153,6 @@ gst_video_encoder_finalize (GObject * object)
     gve->priv->main_pipeline = NULL;
   }
 
-  if (gve->priv->update_id != 0) {
-    g_source_remove (gve->priv->update_id);
-    gve->priv->update_id = 0;
-  }
-
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -434,6 +434,10 @@ gst_video_encoder_select_next_file (GstVideoEncoder *gve)
     gst_video_encoder_create_source (gve, (gchar *) gve->priv->current_file->data);
   } else {
     GST_INFO_OBJECT (gve, "No more files, sending EOS");
+    if (gve->priv->update_id != 0) {
+      g_source_remove (gve->priv->update_id);
+      gve->priv->update_id = 0;
+    }
     /* Enlarge queues to avoid deadlocks */
     g_object_set (gve->priv->aqueue, "max-size-time", 0,
         "max-size-bytes", 0, "max-size-buffers", 0, NULL);
